@@ -1,12 +1,19 @@
 """
 Utilities for the Basic Modeling interface.
 """
-from cmt.bmi.interfaces import (BmiBase, BmiUniformRectilinear,
+from cmt.bmi.interfaces import (BmiBase, BmiExtendedBase)
+from cmt.bmi.interfaces import (BmiNoGrid, BmiUniformRectilinear,
                                 BmiRectilinear, BmiStructured,
-                                BmiUnstructured, BadVarNameError)
+                                BmiUnstructured)
+from cmt.bmi.interfaces import (BadVarNameError, FatalError,
+                                MissingModelAttributeError,
+                                TimeBoundsError,
+                               )
 from cmt.bmi.interfaces import (GRID_TYPE_UNKNOWN,
+                                GRID_TYPE_NONE,
                                 GRID_TYPE_UNIFORM,
                                 GRID_TYPE_RECTILINEAR,
                                 GRID_TYPE_STRUCTURED,
                                 GRID_TYPE_UNSTRUCTURED,
                                )
+import cmt.bmi.examples
