@@ -71,7 +71,7 @@ import sys
 import numpy  # (for: float64, int16, pi, sqrt, zeros)
 import time
 
-import cmt.bmi.examples.water_tank.rainfall as rainfall
+from cmt.bmi.examples.water_tank import InputFile
 from cmt.bmi import BmiBase, BmiNoGrid
 from cmt.bmi import (BadVarNameError, MissingModelAttributeError,
                      FatalError)
@@ -420,7 +420,7 @@ class WaterTank(object):
         # This will be used by the update_rain() method.
         #-------------------------------------------------
         try:
-            self.rain_file = rainfall.InputFile(self.rain_data_filename)
+            self.rain_file = InputFile(self.rain_data_filename)
             self.rain_file.open()
         except IOError:
             self.rain_file = None
@@ -599,7 +599,7 @@ class WaterTank(object):
         if (cfg_file == None):
             cfg_file = self.cfg_file
 
-        tank_file = rainfall.InputFile(cfg_file)
+        tank_file = InputFile(cfg_file)
         tank_file.open()
 
         #------------------------------------------------
